# Generated by Django 4.2.5 on 2025-08-26 14:09

from django.db import migrations, models
import django.utils.timezone


class Migration(migrations.Migration):

    dependencies = [
        ('licensing', '0001_initial'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='license',
            options={'ordering': ['name'], 'verbose_name': 'license', 'verbose_name_plural': 'licenses'},
        ),
        migrations.RemoveField(
            model_name='license',
            name='URL',
        ),
        migrations.AddField(
            model_name='license',
            name='canonical_url',
            field=models.URLField(default='', help_text='A permanent online resource describing the license', max_length=500, unique=True, verbose_name='canonical URL'),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='license',
            name='created_at',
            field=models.DateTimeField(auto_now_add=True, default=django.utils.timezone.now, verbose_name='created at'),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='license',
            name='deprecated_date',
            field=models.DateField(blank=True, help_text='Date when this license was deprecated', null=True, verbose_name='deprecated date'),
        ),
        migrations.AddField(
            model_name='license',
            name='is_active',
            field=models.BooleanField(default=True, help_text='Whether this license is still recommended for use', verbose_name='is active'),
        ),
        migrations.AddField(
            model_name='license',
            name='updated_at',
            field=models.DateTimeField(auto_now=True, verbose_name='updated at'),
        ),
        migrations.AlterField(
            model_name='license',
            name='text',
            field=models.TextField(default='', help_text='The full text of the license', verbose_name='text'),
            preserve_default=False,
        ),
        migrations.AddIndex(
            model_name='license',
            index=models.Index(fields=['is_active'], name='licensing_l_is_acti_edc5ed_idx'),
        ),
        migrations.AddIndex(
            model_name='license',
            index=models.Index(fields=['slug'], name='licensing_l_slug_00bc60_idx'),
        ),
    ]
