# Generated by Django 4.2.9 on 2024-01-29 13:15

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = []

    operations = [
        migrations.CreateModel(
            name="License",
            fields=[
                ("id", models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name="ID")),
                (
                    "name",
                    models.CharField(
                        help_text="The name of the license", max_length=255, unique=True, verbose_name="name"
                    ),
                ),
                (
                    "URL",
                    models.URLField(
                        help_text="A permanent online resource describing the license",
                        unique=True,
                        verbose_name="canonical URL",
                    ),
                ),
                (
                    "description",
                    models.TextField(
                        blank=True,
                        help_text="A short description of the license",
                        null=True,
                        verbose_name="description",
                    ),
                ),
                (
                    "text",
                    models.TextField(
                        blank=True, help_text="The full text of the license", null=True, verbose_name="text"
                    ),
                ),
                ("slug", models.SlugField(blank=True, max_length=255, unique=True, verbose_name="slug")),
            ],
            options={
                "verbose_name": "license",
                "verbose_name_plural": "licenses",
            },
        ),
    ]
